Summary: LIGO Grid-Mapfile Manager
Name: ligo-grid-mapfile-manager
Version: 1.3.0
Release: 1%{?dist}
Source0: http://software.igwn.org/sources/source/%{name}-%{version}.tar.gz
License: GPLv3+
BuildArch: noarch
Url: https://wiki.ligo.org/AuthProject
Packager: Duncan Macleod <duncan.macleod@ligo.org>
Prefix: %{_prefix}

# -- build requirements -----

# macros
BuildRequires: python-srpm-macros
BuildRequires: python-rpm-macros
BuildRequires: python3-rpm-macros

# build
BuildRequires: help2man
BuildRequires: python3
BuildRequires: python%{python3_pkgversion}-setuptools

# Requires->BuildRequires for help2man:
BuildRequires: python%{python3_pkgversion}-ldap3

# -- packages ---------------

## ligo-grid-mapfile-manager
Requires: python%{python3_pkgversion}-lgmm = %{version}-%{release}
%description
%{summary}

%package -n python%{python3_pkgversion}-lgmm
Summary: LIGO Grid-Mapfile Manager python library
Requires: ca-certificates
Requires: python%{python3_pkgversion}-ldap3
%{?python_provide:%python_provide python%{python3_pkgversion}-%{name}}
%description -n python%{python3_pkgversion}-lgmm
The Python %{python3_version} library for the LIGO Grid-Mapfile Manager

# -- build ------------------

%prep
%autosetup -n %{name}-%{version}

%build
%py3_build

%install
# install the software
%py3_install -- --install-scripts %{_sbindir} --install-data /

# generate manpages using help2man
mkdir -p %{buildroot}%{_mandir}/man8
env PYTHONPATH=%{buildroot}%{python3_sitelib} help2man \
	--source %{name} \
	--version-string %{version} \
	--no-info \
	--no-discard-stderr \
	--section 8 \
	--output %{buildroot}%{_mandir}/man8/lgmm.8 \
	--name "LIGO Grid Mapfile Manager" \
	%{buildroot}%{_sbindir}/lgmm
env PYTHONPATH=%{buildroot}%{python3_sitelib} help2man \
	--source %{name} \
	--version-string %{version} \
	--no-info \
	--no-discard-stderr \
	--section 8 \
	--output %{buildroot}%{_mandir}/man8/normalize_grid-mapfile.8 \
	--name "normalize a grid mapfile" \
	%{buildroot}%{_sbindir}/normalize_grid-mapfile

# install configuration template
%{__mkdir} -p %{buildroot}%{_sysconfdir}/lgmm
%{__install} --mode=0644 etc/lgmm_config.py %{buildroot}%{_sysconfdir}/lgmm/lgmm_config.py

# install log rotation configuration
%{__mkdir} -p %{buildroot}%{_sysconfdir}/logrotate.d
%{__install} --mode=0644 etc/lgmm.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/lgmm

# install defaults template
%{__mkdir} -p %{buildroot}%{_sysconfdir}/sysconfig
%{__install} --mode=0644 etc/lgmm.default %{buildroot}%{_sysconfdir}/sysconfig/lgmm

# install the init script
%{__mkdir} -p %{buildroot}%{_unitdir}
%{__install} --mode=0644 etc/lgmm.service.el %{buildroot}%{_unitdir}/lgmm.service

%post
%systemd_post lgmm.service
mkdir -p /var/log/lgmm > /dev/null 2>&1
chown nobody /var/log/lgmm > /dev/null 2>&1

mkdir -p /var/run/lgmm > /dev/null 2>&1
chown nobody /var/run/lgmm > /dev/null 2>&1
chmod 755 /var/run/lgmm > /dev/null 2>&1

%preun
%systemd_preun lgmm.service

%postun
%systemd_postun_with_restart lgmm.service

%clean
rm -rf $RPM_BUILD_ROOT

# -- files ------------------

%files
%license COPYING
%doc README.md
%{_sbindir}/*
%{_mandir}/man8/*
%{_unitdir}/lgmm.service
%config(noreplace) %attr(0644,root,root) /etc/logrotate.d/lgmm
%config(noreplace) %attr(0644,root,root) /etc/sysconfig/lgmm
%config(noreplace) %attr(0644,root,root) /etc/lgmm/lgmm_config.py
%exclude /etc/lgmm/*.pyc
%exclude /etc/lgmm/*.pyo

%files -n python%{python3_pkgversion}-lgmm
%license COPYING
%doc README.md
%{python3_sitelib}/*

# -- changelog --------------

%changelog
* Tue Feb 9 2021 Duncan Macleod <duncan.macleod@ligo.org> - 1.3.0-1
- New binary packaging structure
- Update to python3

* Thu Oct 20 2016 Paul Hopkins <paul.hopkins@ligo.org> - 1.2.0-1
- Cleanly separate the concept of input mapfile and output mapfile
- Add random delay option
- Allow modifications of mapfile using local overrides

* Tue May 10 2016 Paul Hopkins <paul.hopkins@ligo.org> - 1.1.4-1
- Add option for selections of multiple groups
- Add custom LDAP filter option
- Modify init file to create pid directory if required

* Thu Apr 21 2016 Adam Mercer <adam.mercer@ligo.org> - 1.1.3-1
- use /usr/bin/python as interpreter for normalize_grid-mapfile

* Tue May 12 2015 Paul Hopkins <paul.hopkins@ligo.org> - 1.1.2-0
- Only use default usernames if site specific ones do not exist.

* Wed Oct 15 2014 Paul Hopkins <paul.hopkins@ligo.org> - 1.1.1-0
- Prevent inclusion of potentially dangerous grid-subjects.

* Fri Mar 29 2013 Scott Koranda <scott.koranda@ligo.org> - 1.1.0-1
- Added features and no start at boot time.

* Thu Mar 28 2013 Scott Koranda <scott.koranda@ligo.org> - 1.0.3-1
- Fixed sorting issue with account names

* Mon Mar 25 2013 Scott Koranda <scott.koranda@ligo.org> - 1.0.2-1
- Still better init script functionality

* Sun Mar 24 2013 Scott Koranda <scott.koranda@ligo.org> - 1.0.1-1
- Better init script and daemon functionality

* Tue Mar 19 2013 Scott Koranda <scott.koranda@ligo.org> - 1.0.0-1
- Initial version.
